import axios from 'axios';
import dayjs from 'dayjs';
import { useEffect, useState } from 'react';
import { NavigateFunction, useNavigate, useParams } from "react-router-dom";
import './App.css';
import A from './Components/CustomA';

export default function Play() {
	const navigate: NavigateFunction = useNavigate();
	const { id } = useParams();
	const [data, setData] = useState<any>(null)
	const [time, setTime] = useState<string>("")
	const [winTeam, setWinTeam] = useState<string>("")
	const [score, setScore] = useState<string>("")
	const [team, setTeam] = useState<string[]>([])
	const [scoreList, setScoreList] = useState<any[]>([])

	function onClickLobby(): void {
		navigate(`/home/${data.dayOfWeek}`);
	}

	useEffect(() => {
		const data = JSON.stringify({
			"id": id
		});

		const config = {
			method: 'post',
			maxBodyLength: Infinity,
			url: 'https://jianmiau.tk:21880/Badminton/gethistorybyid',
			headers: {
				'Content-Type': 'application/json'
			},
			data: data
		};

		axios.request(config)
			.then((response) => {
				const data: any = response.data[0];
				setData(data);
				document.title = dayjs(data.time * 1000).format("YYYY-MM-DD HH:mm:ss")
			})
			.catch((error) => {
				console.log(error);
			});

	}, [])

	useEffect(() => {
		if (data) {
			const score: number[] = JSON.parse(data.score);
			const win: number = score.indexOf(data.winScore) === -1
				? score.indexOf(score[0] > score[1] ? score[0] : score[1])
				: score.indexOf(data.winScore);
			const team: string[] = JSON.parse(data.team).flat();
			const winTeam: string[] = JSON.parse(data.team)[win];
			const scoreList: number[] = JSON.parse(data.scoreList);
			setTime(dayjs(data.time * 1000).format("YYYY-MM-DD HH:mm:ss"));
			setTeam(team);
			if (win === -1) {
				setWinTeam("不明");
			} else {
				setWinTeam(winTeam[0] + "、" + winTeam[1]);
			}
			setScore(score[0] + "：" + score[1]);
			setScoreList(scoreList);
		}
	}, [data])

	return <>
		<A href="#" onClick={onClickLobby}><h1>返回</h1></A>
		<h1>{winTeam}　　勝利</h1>
		<h1>比分　{score}</h1>
		<table>
			<thead>
				<tr>
					<td colSpan={7} style={{ textAlign: "center" }}><h3>{team[0]}、{team[1]}　vs　{team[2]}、{team[3]}</h3></td>
				</tr>
				<tr>
					<td colSpan={7} style={{ textAlign: "center" }}><h3>{time}</h3></td>
				</tr>
			</thead>
			<thead>
				<tr>
					<th>局數</th>
					<th>連勝</th>
					<th>得分</th>
					<th>發球</th>
					<th>發球</th>
					<th>得分</th>
					<th>連勝</th>
				</tr>
			</thead>
			<tbody>
				{scoreList.map((value: number[], idx: number) => {
					const [round, starter, winCount, winner] = value;
					return <tr key={idx}>
						<td>{round}</td>
						<td>{winCount && [0, 1].includes(starter) ? `${winCount}連勝` : ""}</td>
						<td>{winner === 0 && "O"}</td>
						<td>{[0, 1].includes(starter) ? team[starter] + "　發球" : ""}</td>
						<td>{[2, 3].includes(starter) ? team[starter] + "　發球" : ""}</td>
						<td>{winner === 1 && "O"}</td>
						<td>{winCount && [2, 3].includes(starter) ? `${winCount}連勝` : ""}</td>
					</tr>
				})}
			</tbody>
		</table>
	</>
}